Muex.Reporter (Muex v0.11.2)

Reports mutation testing results to the terminal.

Provides progress updates and final summaries of mutation testing runs.

Summary

Functions

Prints progress for a single mutation result.

Prints a summary of mutation testing results.

Returns a one-line, uncolored summary of the results, such as "Mutation Score: 75.0% (4 mutants: 3 killed, 1 survived, 0 invalid, 0 timed out)".

Functions

summary_line(results)

@spec summary_line([map()]) :: String.t()

Returns a one-line, uncolored summary of the results, such as "Mutation Score: 75.0% (4 mutants: 3 killed, 1 survived, 0 invalid, 0 timed out)".

Equivalent and no-coverage mutants are counted only when there are any, as in print_summary/1. Printed in place of the full summary when the report is written to a file.