Muex. Reporter
(Muex v0.11.2)
Reports mutation testing results to the terminal.
Provides progress updates and final summaries of mutation testing runs.
Summary
Functions
Prints progress for a single mutation result.
Prints a summary of mutation testing results.
Returns a one-line, uncolored summary of the results, such as
"Mutation Score: 75.0% (4 mutants: 3 killed, 1 survived, 0 invalid, 0 timed out)".
Functions
@spec print_progress(map(), non_neg_integer(), non_neg_integer()) :: :ok
Prints progress for a single mutation result.
Parameters
result- A single mutation resultindex- Current mutation indextotal- Total number of mutations
@spec print_summary([map()]) :: :ok
Prints a summary of mutation testing results.
Parameters
results- List of mutation results
Returns a one-line, uncolored summary of the results, such as
"Mutation Score: 75.0% (4 mutants: 3 killed, 1 survived, 0 invalid, 0 timed out)".
Equivalent and no-coverage mutants are counted only when there are any, as in
print_summary/1. Printed in place of the full summary when the report is
written to a file.